<?php 
/*
Plugin Name: Easy Bulk Subpage Creator
Description: A handy tool for batch creation of subpages. 
Author: Manoj Sathyavrathan
Version: 1.5

*/

add_action( 'admin_menu', 'man_ebsc_easy_bulk_subpage_menu' );

function man_ebsc_easy_bulk_subpage_menu() {
	add_options_page( 'Easy Bulk Subpage Creator', 'Easy Bulk Subpage Creator', 'manage_options', 'ebsc-page-creator', 'man_ebsc_easy_bulk_page_options','dashicons-welcome-add-page' );
}

function man_ebsc_easy_bulk_page_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( 'You do not have sufficient permissions to access this page.' );
	}
	
	if(isset($_POST['val1'])){
		$man_ebsc_parent_id = htmlentities($_POST['val1']);
	}
	
	if(isset($_POST['textarea'])){
		$man_ebsc_save_page_title_contents = htmlentities($_POST['textarea']);
	}
	
	if(isset($_POST['man_ebsc_page_id'])){
		$man_ebsc_parent_id = $_POST['man_ebsc_page_id'];
	}
	?>
	<div class="wrap">
		<h1>Easy Bulk Subpage Creator</h1>
		<form action="" method="post">
			
			Add sub-page titles one per line below text box.<br><br>
			<textarea name="textarea" rows="13" cols="100" class="full-width" ><?php echo $man_ebsc_save_page_title_contents ?></textarea><br/><br/>
			
			<b>Parent:</b>  
			 <?php wp_dropdown_pages( array(
	'name'		  => 'man_ebsc_page_id',
	'show_option_none' => 'Select a page',
	'option_none_value' => 'man_ebsc_page_none',
	'selected' => $man_ebsc_parent_id,
) ); ?> <br/><br/>
			
			
			<input type="submit" name="create_pages" value="Create Pages"></input>
			<?php wp_nonce_field( 'man_ebsc_easy_bulk_insert', '2576b889a954d26' ); ?>
		</form>
	</div>
<?php
	
if( isset($_POST['create_pages']) ) {

	if ( ! isset( $_POST['2576b889a954d26'] ) 
		|| ! wp_verify_nonce( $_POST['2576b889a954d26'], 'man_ebsc_easy_bulk_insert' ) 
	) {
	   print "Sorry, you don't have access.";
	   exit;

	} else {
		$man_ebsc_texts = trim($_POST['textarea']);
		
		if ( "" == $man_ebsc_texts && 'man_ebsc_page_none' == $man_ebsc_parent_id ) {
			?>
				<div class="notice notice-error is-dismissible">
					<p><?php echo "Please enter at least one title, select a page from the drop down list and continue." ?></p>
				</div>
			<?php
			exit;
		}
		
		if ( "" == $man_ebsc_texts ) {
			?>
				<div class="notice notice-error is-dismissible">
					<p><?php echo "Please enter at least one title and continue." ?></p>
				</div>
			<?php
			exit;
		}
		
		
		
		if ( "" == $man_ebsc_parent_id ) {
			?>
				<div class="notice notice-error is-dismissible">
					<p><?php echo "Please enter a valid parent page id and continue." ?></p>
				</div>
			<?php
			exit;
		}
		
		if ( 'man_ebsc_page_none' == $man_ebsc_parent_id ) {
			?>
				<div class="notice notice-error is-dismissible">
					<p><?php echo "Please select a page from the drop down list and continue." ?></p>
				</div>
			<?php
			exit;
		}
		
		// Total pages count
		$man_ebsc_count_pages = 0;
		
		$man_ebsc_texts = explode ("\n", $man_ebsc_texts);
		foreach($man_ebsc_texts as $man_ebsc_text) {
			$new_page_title = $man_ebsc_text;
				$man_ebsc_new_page = array(
					'post_type' => 'page',
					'post_title' => $new_page_title,
					'post_status' => 'publish',
					'post_parent' => $man_ebsc_parent_id,
					'menu_order' => $man_ebsc_count_pages,
			);
			
			// If parent page exists ....
			if ( !false == get_post_status ( $man_ebsc_parent_id ) ) {
				if( !empty($man_ebsc_parent_id)) {
					
					//  Create sub page
					$new_page_id = wp_insert_post($man_ebsc_new_page);
					$man_ebsc_count_pages++;
				}
			}
		}
		
		if ( $man_ebsc_count_pages >0 ) {
			$pageID = $man_ebsc_parent_id;
			$page = get_post($pageID);
			$man_ebsc_title = $page->post_title;
			
			?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo "Total $man_ebsc_count_pages sub-pages created successfully for the '$man_ebsc_title' parent page." ?></p>
				</div>
			<?php
			
		} else {
		
			?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo "No pages created." ?></p>
				</div>
			<?php
			
		}
	}	
}
}
?>